@@ -4,7 +4,7 @@ function(para) {
     ALPHA <- para$para[1] 
     BETA  <- para$para[2] 
     if(ALPHA <= 0 | BETA <= 1) {
-      warning("Parameters are invalid.")
+      warning("Parameters are invalid")
       return(FALSE)
     }
     return(TRUE)
