@@ -9,7 +9,8 @@ function(para) {
               LCV  = NULL,
               L3   = NULL,
               L4   = NULL,
-              L5   = NULL
+              L5   = NULL,
+              source = "lmomkap--ordinary"
              )
     BETA <- matrix(nrow = 5, ncol = 1)
 
